<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="76"/>
        <source>Enter the number to configure: </source>
        <translation>Enter the number to configure: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="81"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="16"/>
        <source>Loading packages...</source>
        <translation>Loading packages...</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="17"/>
        <source>%1/%2 loaded</source>
        <translation>%1/%2 loaded</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="20"/>
        <source>Initializing...</source>
        <translation>Initializing...</translation>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="17"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="107"/>
        <source>Package Installer</source>
        <translation>Package Installer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="115"/>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="598"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="699"/>
        <source>Installing other packages... Please open it later.</source>
        <translation>Installing other packages... Please open it later.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="602"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation>Parsing failed: An illegal file structure was found in the manifest file!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="604"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation>Parsing failed: An illegal version number was found in the manifest file!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="606"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation>No deb packages found. Please check the folder.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="718"/>
        <source>The %1 package may be broken</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="726"/>
        <source>You can only install local %1 packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="734"/>
        <source>No permission to access this folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The deb package may be broken</source>
        <translation type="vanished">The deb package may be broken</translation>
    </message>
    <message>
        <source>You can only install local deb packages</source>
        <translation type="vanished">You can only install local deb packages</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="750"/>
        <source>Already Added</source>
        <translation>Already Added</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="759"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1 does not exist, please reselect</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="381"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="766"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="907"/>
        <source>Bulk Install</source>
        <translation>Bulk Install</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="94"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="111"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Installation failed, please check your network connection</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="97"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>Installation failed, please check for updates in Control Center</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="99"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="103"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="115"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Installation failed, insufficient disk space</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="120"/>
        <source>No digital signature</source>
        <translation>No digital signature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="124"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="754"/>
        <source>Invalid digital signature</source>
        <translation>Invalid digital signature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="130"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="744"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1663"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>The administrator has set policies to prevent installation of this package</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="136"/>
        <source>Installation Failed</source>
        <translation>Installation Failed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="732"/>
        <source>current system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="735"/>
        <source>%2 has been installed in %1, please uninstall this package before installing it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="741"/>
        <source>Broken dependencies, try installing the app in compatibility mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="756"/>
        <source>Failed to install %1</source>
        <translation>Failed to install %1</translation>
    </message>
    <message>
        <source>Failed to install %1: no valid digital singature</source>
        <translation type="vanished">Failed to install %1: no valid digital singature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1116"/>
        <source>Unable to install - no digital signature</source>
        <translation>Unable to install - no digital signature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1117"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>Please go to Control Center to enable developer mode and try again. Proceed?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1120"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1121"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Proceed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1074"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1176"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1665"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1078"/>
        <source>Failed to install %1: no valid digital signature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1214"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>This package does not have a valid digital signature. Continue with the installation?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1216"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1217"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continue</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1072"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1173"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1662"/>
        <source>Unable to install</source>
        <translation>Unable to install</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1174"/>
        <source>This package does not have a valid digital signature</source>
        <translation>This package does not have a valid digital signature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="759"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="764"/>
        <source>Broken dependencies: %1</source>
        <translation>Broken dependencies: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="128"/>
        <source>Authentication failed</source>
        <translation>Authentication failed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="711"/>
        <source>Unmatched package architecture</source>
        <translation>Unmatched package architecture</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="48"/>
        <source>Drag deb packages here</source>
        <translation>Drag deb packages here</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="90"/>
        <source>Select File</source>
        <translation>Select File</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="34"/>
        <source>Show details</source>
        <translation>Show details</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="34"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Collapse</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="169"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Install</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="170"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Done</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="172"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Back</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="501"/>
        <source>Install %1 will remove: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="517"/>
        <source>Dependencies in the repository</source>
        <translation>Dependencies in the repository</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="523"/>
        <source>Missing dependencies</source>
        <translation>Missing dependencies</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="575"/>
        <source>Installing dependencies: %1</source>
        <translation>Installing dependencies: %1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="82"/>
        <source>Same version installed</source>
        <translation>Same version installed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="85"/>
        <source>Earlier version installed: %1</source>
        <translation>Earlier version installed: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="89"/>
        <source>Later version installed: %1</source>
        <translation>Later version installed: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="94"/>
        <source>Unmatched package architecture</source>
        <translation>Unmatched package architecture</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="22"/>
        <source>Select all</source>
        <translation>Select all</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="23"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Install</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="57"/>
        <source>Installing</source>
        <translation>Installing</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="61"/>
        <source>Installed</source>
        <translation>Installed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="69"/>
        <source>Failed</source>
        <translation>Failed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="65"/>
        <source>Waiting</source>
        <translation>Waiting</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="232"/>
        <source>Same version installed</source>
        <translation>Same version installed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="234"/>
        <source>Later version installed: %1</source>
        <translation>Later version installed: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="236"/>
        <source>Earlier version installed: %1</source>
        <translation>Earlier version installed: %1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="161"/>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="31"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="49"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="51"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Collapse</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>Basic</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>Check digital signatures if the developer mode is enabled</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="82"/>
        <source>To install unsigned apps, go to Security Center &gt; Tools &gt; App Security, and select the app types that can be installed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="84"/>
        <source>Security Center &gt; Tools &gt; App Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/uab/uab_package.cpp" line="45"/>
        <source>The system has not installed Linglong environment, please install it first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="42"/>
        <source>Unable to install</source>
        <translation type="unfinished">Unable to install</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="44"/>
        <source>This package does not have a valid digital signature and has been blocked from installing/running. Go to Security Center &gt; Tools &gt; App Security to change the settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="47"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="48"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation type="unfinished">Proceed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="264"/>
        <source>Will remove: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="974"/>
        <source>Collapse</source>
        <translation>Collapse</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="482"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1151"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1338"/>
        <source>Reinstall</source>
        <translation>Reinstall</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1155"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1342"/>
        <source>Later version installed: %1</source>
        <translation>Later version installed: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1156"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1343"/>
        <source>Downgrade</source>
        <translation>Downgrade</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1160"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1347"/>
        <source>Earlier version installed: %1</source>
        <translation>Earlier version installed: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1243"/>
        <source>Installing dependencies: %1</source>
        <translation>Installing dependencies: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1390"/>
        <source>Failed to install %1</source>
        <translation>Failed to install %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="228"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="177"/>
        <source>Select a compatibility mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="474"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Install</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="478"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>Remove</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="486"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="490"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Back</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="494"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Done</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="731"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="770"/>
        <source>Trying to install %2 in %1 compatibility mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="808"/>
        <source>Uninstalling %2 from %1 compatibility mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="928"/>
        <source>%2 was successfully installed to %1 compatibility mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="932"/>
        <source>Installed successfully</source>
        <translation>Installed successfully</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="941"/>
        <source>%2 has been successfully uninstalled from %1 compatibility mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="945"/>
        <source>Uninstalled successfully</source>
        <translation>Uninstalled successfully</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="964"/>
        <source>Uninstall Failed</source>
        <translation>Uninstall Failed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1004"/>
        <source>Install %1 will remove: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1024"/>
        <source>Dependencies in the repository</source>
        <translation>Dependencies in the repository</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1030"/>
        <source>Missing dependencies</source>
        <translation>Missing dependencies</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1161"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1348"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Update</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1395"/>
        <source>Invalid digital signature</source>
        <translation type="unfinished">Invalid digital signature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="216"/>
        <source>Name: </source>
        <translation>Name: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1150"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1337"/>
        <source>Same version installed</source>
        <translation>Same version installed</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="49"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="717"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="756"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="925"/>
        <source>Show details</source>
        <translation>Show details</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="31"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <source>Show dependencies</source>
        <translation>Show dependencies</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="794"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="938"/>
        <source>Show details</source>
        <translation>Show details</translation>
    </message>
</context>
<context>
    <name>Uab::UabPackageListModel</name>
    <message>
        <location filename="../src/deb-installer/uab/uab_package_list_model.cpp" line="456"/>
        <source>Installation Failed</source>
        <translation>Installation Failed</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Show related packages</source>
        <translation>Show related packages</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Collapse</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="129"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>Are you sure you want to uninstall %1?
All dependencies will also be removed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="131"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>Are you sure you want to uninstall %1?
The system or other applications may not work properly</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="169"/>
        <source>Are you sure you want to uninstall %2 
from %1 compatibility mode?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="47"/>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <source>Package Installer</source>
        <translation>Package Installer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>Package Installer helps users install and remove local packages, and supports bulk installation.</translation>
    </message>
</context>
</TS>
